@@ -173,7 +173,9 @@ _gnome_vfs_read_mime_from_buffer (GnomeVFSMimeSniffBuffer *buffer)
 	GnomeVFSResult result = GNOME_VFS_OK;
 	const char *mime_type;
 
+	G_LOCK (mime_mutex);
 	max_extents = xdg_mime_get_max_buffer_extents ();
+	G_UNLOCK (mime_mutex);
 	max_extents = CLAMP (max_extents, 0, MAX_SNIFF_BUFFER_ALLOWED);
 
 	if (!buffer->read_whole_file) {
@@ -605,7 +607,9 @@ gnome_vfs_mime_type_is_equal (const char *a,
 	g_return_val_if_fail (a != NULL, FALSE);
 	g_return_val_if_fail (b != NULL, FALSE);
 
+	G_LOCK (mime_mutex);
 	xdg_mime_mime_type_equal (a, b);
+	G_UNLOCK (mime_mutex);
 
 	return FALSE;
 }
@@ -639,8 +643,13 @@ gnome_vfs_mime_type_get_equivalence (const char *mime_type,
 
 	if (gnome_vfs_mime_type_is_equal (mime_type, base_mime_type)) {
 		return GNOME_VFS_MIME_IDENTICAL;
-	} else if (xdg_mime_mime_type_subclass (mime_type, base_mime_type)) {
-		return GNOME_VFS_MIME_PARENT;
+	} else {
+		G_LOCK (mime_mutex);
+		if (xdg_mime_mime_type_subclass (mime_type, base_mime_type)) {
+			G_UNLOCK (mime_mutex);
+			return GNOME_VFS_MIME_PARENT;
+		}
+		G_UNLOCK (mime_mutex);
 	}
 
 	return GNOME_VFS_MIME_UNRELATED;
