@@ -25,7 +25,19 @@
 #ifndef GNOME_VFS_PRIVATE_H
 #define GNOME_VFS_PRIVATE_H
 
-#define GNOME_VFS_MODULE_DIR     LIBDIR "/gnome-vfs-2.0/modules"
-#define GNOME_VFS_MODULE_CFGDIR  SYSCONFDIR "/gnome-vfs-2.0/modules"
+#include <glib.h>
+#include <libgnomevfs/gnome-vfs-volume-monitor.h>
+
+#define GNOME_VFS_MODULE_SUBDIR  "gnome-vfs-2.0/modules"
+
+typedef void (*GnomeVFSDaemonForceProbeCallback) (GnomeVFSVolumeMonitor *volume_monitor);
+
+void gnome_vfs_set_is_daemon (GType volume_monitor_type,
+			      GnomeVFSDaemonForceProbeCallback force_probe);
+gboolean gnome_vfs_get_is_daemon (void);
+
+GType _gnome_vfs_get_daemon_volume_monitor_type (void);
+GnomeVFSDaemonForceProbeCallback _gnome_vfs_get_daemon_force_probe_callback (void);
+
 
 #endif /* GNOME_VFS_PRIVATE_H */
